@@ -10,6 +10,7 @@ import * as uuid from "uuid";
 import type { ElectronApplication, Frame, Page } from "playwright";
 import { _electron as electron } from "playwright";
 import { noop } from "lodash";
+import { disposer } from "../../src/common/utils";
 
 export const appPaths: Partial<Record<NodeJS.Platform, string>> = {
   "win32": "./dist/win-unpacked/OpenLens.exe",
@@ -26,19 +27,46 @@ export function describeIf(condition: boolean) {
 }
 
 async function getMainWindow(app: ElectronApplication, timeout = 50_000): Promise<Page> {
-  const deadline = Date.now() + timeout;
+  return new Promise((resolve, reject) => {
+    const cleanup = disposer();
+    let stdoutBuf = "";
+
+    const onWindow = (page: Page) => {
+      console.log(`Page opened: ${page.url()}`);
 
-  for (; Date.now() < deadline;) {
-    for (const page of app.windows()) {
       if (page.url().startsWith("http://localhost")) {
-        return page;
+        cleanup();
+        console.log(stdoutBuf);
+        resolve(page);
       }
-    }
+    };
 
-    await new Promise(resolve => setTimeout(resolve, 2_000));
-  }
+    app.on("window", onWindow);
+    cleanup.push(() => app.off("window", onWindow));
 
-  throw new Error(`Lens did not open the main window within ${timeout}ms`);
+    const onClose = () => {
+      cleanup();
+      reject(new Error("App has unnexpectedly closed"));
+    };
+
+    app.on("close", onClose);
+    cleanup.push(() => app.off("close", onClose));
+
+    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
+    const stdout = app.process().stdout!;
+    const onData = (chunk: any) => stdoutBuf += chunk.toString();
+
+    stdout.on("data", onData);
+    cleanup.push(() => stdout.off("data", onData));
+
+    const timeoutId = setTimeout(() => {
+      cleanup();
+      console.log(stdoutBuf);
+      reject(new Error(`Lens did not open the main window within ${timeout}ms`));
+    }, timeout);
+
+    cleanup.push(() => clearTimeout(timeoutId));
+  });
 }
 
 async function attemptStart() {
@@ -57,7 +85,7 @@ async function attemptStart() {
       ...process.env,
     },
     timeout: 100_000,
-  } as Parameters<typeof electron["launch"]>[0]);
+  });
 
   try {
     const window = await getMainWindow(app);
@@ -78,6 +106,8 @@ async function attemptStart() {
 }
 
 export async function start() {
+  console.log(process.env);
+
   // this is an attempted workaround for an issue with playwright not always getting the main window when using Electron 14.2.4 (observed on windows)
   for (let i = 0; ; i++) {
     try {
