@@ -5,7 +5,7 @@
 
 import type { AppEvent } from "../app-event-bus/event-bus";
 import { appEventBus } from "../app-event-bus/event-bus";
-import { Console } from "console";
+import { assert, Console } from "console";
 import { stdout, stderr } from "process";
 
 console = new Console(stdout, stderr);
@@ -13,14 +13,15 @@ console = new Console(stdout, stderr);
 describe("event bus tests", () => {
   describe("emit", () => {
     it("emits an event", () => {
-      let event: AppEvent = null;
+      let event: AppEvent | undefined;
 
       appEventBus.addListener((data) => {
         event = data;
       });
 
       appEventBus.emit({ name: "foo", action: "bar" });
-      expect(event.name).toBe("foo");
+      assert(event);
+      expect(event?.name).toBe("foo");
     });
   });
 });
