@@ -3,14 +3,13 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import type { KubeJsonApiData } from "./kube-json-api";
 import type { KubeStatusData } from "./kube-object";
 
-export type IKubeWatchEvent<T extends KubeJsonApiData> = {
-  type: "ADDED" | "MODIFIED" | "DELETED";
-  object: T;
+export type IKubeWatchEvent<T> = {
+  readonly type: "ADDED" | "MODIFIED" | "DELETED";
+  readonly object: T;
 } | {
-  type: "ERROR";
-  object: KubeStatusData;
+  readonly type: "ERROR";
+  readonly object?: KubeStatusData;
 };
 
