@@ -10,7 +10,7 @@ import AbortController from "abort-controller";
  * but won't make the parent abort if this aborts (single direction)
  */
 export class WrappedAbortController extends AbortController {
-  constructor(parent?: AbortController) {
+  constructor(parent?: AbortController | undefined) {
     super();
 
     parent?.signal.addEventListener("abort", () => {
