@@ -3,7 +3,7 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import "abort-controller/polyfill";
+import type { AbortSignal } from "abort-controller";
 
 /**
  * Creates a new promise that will be rejected when the signal rejects.
@@ -11,7 +11,7 @@ import "abort-controller/polyfill";
  * Useful for `Promise.race()` applications.
  * @param signal The AbortController's signal to reject with
  */
-export function rejectPromiseBy(signal: AbortSignal): Promise<void> {
+export function rejectPromiseBy(signal: AbortSignal): Promise<never> {
   return new Promise((_, reject) => {
     signal.addEventListener("abort", reject);
   });
