@@ -3,12 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { isLinux } from "../vars";
+import platformInjectable from "./platform.injectable";
 
 const isLinuxInjectable = getInjectable({
   id: "is-linux",
-  instantiate: () => isLinux,
-  causesSideEffects: true,
+
+  instantiate: (di) => {
+    const platform = di.inject(platformInjectable);
+
+    return platform === "linux";
+  },
 });
 
 export default isLinuxInjectable;
