@@ -3,12 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { isMac } from "../vars";
+import platformInjectable from "./platform.injectable";
 
 const isMacInjectable = getInjectable({
   id: "is-mac",
-  instantiate: () => isMac,
-  causesSideEffects: true,
+
+  instantiate: (di) => {
+    const platform = di.inject(platformInjectable);
+
+    return platform === "darwin";
+  },
 });
 
 export default isMacInjectable;
