@@ -3,11 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
+import environmentVariablesInjectable from "../utils/environment-variables.injectable";
 
 const isProductionInjectable = getInjectable({
   id: "is-production",
-  instantiate: () => process.env.NODE_ENV === "production",
-  causesSideEffects: true,
+
+  instantiate: (di) => {
+    const { NODE_ENV: nodeEnv } = di.inject(environmentVariablesInjectable);
+
+    return nodeEnv === "production";
+  },
 });
 
 export default isProductionInjectable;
