@@ -2,6 +2,7 @@
  * Copyright (c) OpenLens Authors. All rights reserved.
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
+import type { IComputedValue } from "mobx";
 import type { PageParamInit, PageParam } from "../../renderer/navigation";
 
 // Extensions-api -> Custom page registration
@@ -14,6 +15,7 @@ export interface PageRegistration {
   id?: string;
   params?: PageParams<string | Omit<PageParamInit<any>, "name" | "prefix">>;
   components: PageComponents;
+  enabled?: IComputedValue<boolean>;
 }
 
 export interface PageComponents {
@@ -40,6 +42,6 @@ export interface RegisteredPage {
   id: string;
   extensionId: string;
   url: string; // registered extension's page URL (without page params)
-  params: PageParams<PageParam>; // normalized params
+  params: PageParams<PageParam<any>>; // normalized params
   components: PageComponents; // normalized components
 }
