@@ -3,10 +3,16 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
+import environmentVariablesInjectable from "../../../common/utils/environment-variables.injectable";
 
 const directoryForIntegrationTestingInjectable = getInjectable({
   id: "directory-for-integration-testing",
-  instantiate: () => process.env.CICD,
+
+  instantiate: (di) => {
+    const environmentVariables = di.inject(environmentVariablesInjectable);
+
+    return environmentVariables.CICD;
+  },
 });
 
 export default directoryForIntegrationTestingInjectable;
