@@ -5,24 +5,19 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { computed } from "mobx";
 import selectedUpdateChannelInjectable from "../../../common/application-update/selected-update-channel/selected-update-channel.injectable";
-import appVersionInjectable from "../../../common/vars/app-version.injectable";
-import { SemVer } from "semver";
+import releaseChannelInjectable from "../../../common/vars/release-channel.injectable";
 
 const updateCanBeDowngradedInjectable = getInjectable({
   id: "update-can-be-downgraded",
 
   instantiate: (di) => {
     const selectedUpdateChannel = di.inject(selectedUpdateChannelInjectable);
-    const appVersion = di.inject(appVersionInjectable);
+    const releaseChannel = di.inject(releaseChannelInjectable);
 
-    return computed(() => {
-      const semVer = new SemVer(appVersion);
-
-      return (
-        semVer.prerelease[0] !==
-        selectedUpdateChannel.value.get().id
-      );
-    });
+    return computed(() => (
+      selectedUpdateChannel.value.get().id === "latest"
+      && releaseChannel.get() !== "latest"
+    ));
   },
 });
 
