@@ -5,20 +5,26 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import selfsigned from "selfsigned";
 import type { Cluster } from "../../common/cluster/cluster";
+import type { ClusterContextHandler } from "./context-handler";
 import { ContextHandler } from "./context-handler";
 import createKubeAuthProxyInjectable from "../kube-auth-proxy/create-kube-auth-proxy.injectable";
 import { getKubeAuthProxyCertificate } from "../kube-auth-proxy/get-kube-auth-proxy-certificate";
 import URLParse from "url-parse";
+import prometheusProviderRegistryInjectable from "../prometheus/prometheus-provider-registry.injectable";
 
 const createContextHandlerInjectable = getInjectable({
   id: "create-context-handler",
 
   instantiate: (di) => {
-    return (cluster: Cluster) => {
+    const createKubeAuthProxy = di.inject(createKubeAuthProxyInjectable);
+    const prometheusProviderRegistry = di.inject(prometheusProviderRegistryInjectable);
+
+    return (cluster: Cluster): ClusterContextHandler => {
       const clusterUrl = new URLParse(cluster.apiUrl);
 
       const dependencies = {
-        createKubeAuthProxy: di.inject(createKubeAuthProxyInjectable),
+        createKubeAuthProxy,
+        prometheusProviderRegistry,
         authProxyCa: getKubeAuthProxyCertificate(clusterUrl.hostname, selfsigned.generate).cert,
       };
 
