@@ -6,19 +6,19 @@
 import type { Cluster } from "../../common/cluster/cluster";
 import type { Kubectl } from "../kubectl/kubectl";
 import type WebSocket from "ws";
-import { shellEnv } from "../utils/shell-env";
-import { app } from "electron";
 import { clearKubeconfigEnvVars } from "../utils/clear-kube-env-vars";
 import path from "path";
 import os, { userInfo } from "os";
-import { isMac, isWindows } from "../../common/vars";
-import { UserStore } from "../../common/user-store";
-import * as pty from "node-pty";
+import type * as pty from "node-pty";
 import { appEventBus } from "../../common/app-event-bus/event-bus";
 import logger from "../logger";
 import { stat } from "fs/promises";
 import { getOrInsertWith } from "../../common/utils";
 import { type TerminalMessage, TerminalChannels } from "../../common/terminal/channels";
+import type { Logger } from "../../common/logger";
+import type { ComputeShellEnvironment } from "../utils/shell-env/compute-shell-environment.injectable";
+import type { SpawnPty } from "./spawn-pty.injectable";
+import type { InitializableState } from "../../common/initializable-state/create";
 
 export class ShellOpenError extends Error {
   constructor(message: string, options?: ErrorOptions) {
@@ -104,6 +104,24 @@ export enum WebSocketCloseEvent {
   TlsHandshake = 1015,
 }
 
+export interface ShellSessionDependencies {
+  readonly isWindows: boolean;
+  readonly isMac: boolean;
+  readonly logger: Logger;
+  readonly resolvedShell: string | undefined;
+  readonly appName: string;
+  readonly buildVersion: InitializableState<string>;
+  computeShellEnvironment: ComputeShellEnvironment;
+  spawnPty: SpawnPty;
+}
+
+export interface ShellSessionArgs {
+  kubectl: Kubectl;
+  websocket: WebSocket;
+  cluster: Cluster;
+  tabId: string;
+}
+
 export abstract class ShellSession {
   abstract readonly ShellType: string;
 
@@ -130,17 +148,20 @@ export abstract class ShellSession {
   protected readonly kubectlBinDirP: Promise<string>;
   protected readonly kubeconfigPathP: Promise<string>;
   protected readonly terminalId: string;
+  protected readonly kubectl: Kubectl;
+  protected readonly websocket: WebSocket;
+  protected readonly cluster: Cluster;
 
   protected abstract get cwd(): string | undefined;
 
-  protected ensureShellProcess(shell: string, args: string[], env: Record<string, string | undefined>, cwd: string): { shellProcess: pty.IPty; resume: boolean } {
+  protected ensureShellProcess(shell: string, args: string[], env: Partial<Record<string, string>>, cwd: string): { shellProcess: pty.IPty; resume: boolean } {
     const resume = ShellSession.processes.has(this.terminalId);
     const shellProcess = getOrInsertWith(ShellSession.processes, this.terminalId, () => (
-      pty.spawn(shell, args, {
+      this.dependencies.spawnPty(shell, args, {
         rows: 30,
         cols: 80,
         cwd,
-        env: env as Record<string, string>,
+        env,
         name: "xterm-256color",
         // TODO: Something else is broken here so we need to force the use of winPty on windows
         useConpty: false,
@@ -152,10 +173,13 @@ export abstract class ShellSession {
     return { shellProcess, resume };
   }
 
-  constructor(protected readonly kubectl: Kubectl, protected readonly websocket: WebSocket, protected readonly cluster: Cluster, terminalId: string) {
+  constructor(protected readonly dependencies: ShellSessionDependencies, args: ShellSessionArgs) {
+    this.cluster = args.cluster;
+    this.kubectl = args.kubectl;
+    this.websocket = args.websocket;
     this.kubeconfigPathP = this.cluster.getProxyKubeconfigPath();
     this.kubectlBinDirP = this.kubectl.binDir();
-    this.terminalId = `${cluster.id}:${terminalId}`;
+    this.terminalId = `${this.cluster.id}:${args.tabId}`;
   }
 
   protected send(message: TerminalMessage): void {
@@ -165,7 +189,7 @@ export abstract class ShellSession {
   protected async getCwd(env: Record<string, string | undefined>): Promise<string> {
     const cwdOptions = [this.cwd];
 
-    if (isWindows) {
+    if (this.dependencies.isWindows) {
       cwdOptions.push(
         env.USERPROFILE,
         os.homedir(),
@@ -177,7 +201,7 @@ export abstract class ShellSession {
         os.homedir(),
       );
 
-      if (isMac) {
+      if (this.dependencies.isMac) {
         cwdOptions.push("/Users");
       } else {
         cwdOptions.push("/home");
@@ -313,19 +337,27 @@ export abstract class ShellSession {
   }
 
   protected async getShellEnv() {
-    const shell = UserStore.getInstance().resolvedShell;
-    const env = clearKubeconfigEnvVars(JSON.parse(JSON.stringify(await shellEnv(shell || userInfo().shell))));
-    const pathStr = [await this.kubectlBinDirP, ...this.getPathEntries(), process.env.PATH].join(path.delimiter);
+    const shell = this.dependencies.resolvedShell || userInfo().shell;
+    const result = await this.dependencies.computeShellEnvironment(shell);
+    const rawEnv = (() => {
+      if (result.callWasSuccessful) {
+        return result.response ?? process.env;
+      }
+
+      return process.env;
+    })();
+
+    const env = clearKubeconfigEnvVars(JSON.parse(JSON.stringify(rawEnv)));
+    const pathStr = [await this.kubectlBinDirP, ...this.getPathEntries(), env.PATH].join(path.delimiter);
 
     delete env.DEBUG; // don't pass DEBUG into shells
 
-    if (isWindows) {
-      env.SystemRoot = process.env.SystemRoot;
+    if (this.dependencies.isWindows) {
       env.PTYSHELL = shell || "powershell.exe";
       env.PATH = pathStr;
       env.LENS_SESSION = "true";
       env.WSLENV = [
-        process.env.WSLENV,
+        env.WSLENV,
         "KUBECONFIG/up:LENS_SESSION/u",
       ]
         .filter(Boolean)
@@ -345,8 +377,8 @@ export abstract class ShellSession {
 
     env.PTYPID = process.pid.toString();
     env.KUBECONFIG = await this.kubeconfigPathP;
-    env.TERM_PROGRAM = app.getName();
-    env.TERM_PROGRAM_VERSION = app.getVersion();
+    env.TERM_PROGRAM = this.dependencies.appName;
+    env.TERM_PROGRAM_VERSION = this.dependencies.buildVersion.get();
 
     if (this.cluster.preferences.httpsProxy) {
       env.HTTPS_PROXY = this.cluster.preferences.httpsProxy;
