@@ -6,7 +6,7 @@ import { getInjectable } from "@ogre-tools/injectable";
 import userStoreFileNameMigrationInjectable from "../../common/user-store/file-name-migration.injectable";
 import userStoreInjectable from "../../common/user-store/user-store.injectable";
 import { beforeApplicationIsLoadingInjectionToken } from "../start-main-application/runnable-tokens/before-application-is-loading-injection-token";
-import initDefaultUpdateChannelInjectableInjectable from "../vars/default-update-channel/init.injectable";
+import initDefaultUpdateChannelInjectable from "../vars/default-update-channel/init.injectable";
 
 const initUserStoreInjectable = getInjectable({
   id: "init-user-store",
@@ -15,11 +15,12 @@ const initUserStoreInjectable = getInjectable({
     const userStoreFileNameMigration = di.inject(userStoreFileNameMigrationInjectable);
 
     return {
+      id: "init-user-store",
       run: async () => {
         await userStoreFileNameMigration();
         userStore.load();
       },
-      runAfter: di.inject(initDefaultUpdateChannelInjectableInjectable),
+      runAfter: di.inject(initDefaultUpdateChannelInjectable),
     };
   },
   injectionToken: beforeApplicationIsLoadingInjectionToken,
