@@ -8,6 +8,7 @@ import EventEmitter from "events";
 import type TypedEventEmitter from "typed-emitter";
 import type { Arguments } from "typed-emitter";
 import { isDevelopment } from "../../common/vars";
+import type { Defaulted } from "../utils";
 import { TerminalChannels, type TerminalMessage } from "../../common/terminal/channels";
 
 interface WebsocketApiParams {
@@ -63,8 +64,6 @@ export interface WebSocketEvents {
   close: () => void;
 }
 
-type Defaulted<Params, DefaultParams extends keyof Params> = Required<Pick<Params, DefaultParams>> & Omit<Params, DefaultParams>;
-
 export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter as { new<T>(): TypedEventEmitter<T> })<Events> {
   protected socket: WebSocket | null = null;
   protected pendingCommands: string[] = [];
@@ -74,7 +73,7 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
 
   @observable readyState = WebSocketApiState.PENDING;
 
-  private static defaultParams = {
+  private static readonly defaultParams = {
     logging: isDevelopment,
     reconnectDelay: 10,
     flushOnOpen: true,
@@ -84,7 +83,10 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
   constructor(params: WebsocketApiParams) {
     super();
     makeObservable(this);
-    this.params = Object.assign({}, WebSocketApi.defaultParams, params);
+    this.params = {
+      ...WebSocketApi.defaultParams,
+      ...params,
+    };
     const { pingInterval } = this.params;
 
     if (pingInterval) {
@@ -92,12 +94,8 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
     }
   }
 
-  get isConnected() {
-    return this.socket?.readyState === WebSocket.OPEN && this.isOnline;
-  }
-
-  get isOnline() {
-    return navigator.onLine;
+  isConnected(): this is (WebSocketApi<Events> & { socket: WebSocket }) {
+    return this.socket?.readyState === WebSocket.OPEN;
   }
 
   connect(url: string) {
@@ -114,7 +112,7 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
   }
 
   ping() {
-    if (this.isConnected) {
+    if (this.isConnected()) {
       this.send(this.params.pingMessage);
     }
   }
@@ -145,7 +143,7 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
   }
 
   send(command: string) {
-    if (this.isConnected) {
+    if (this.isConnected()) {
       this.socket.send(command);
     } else {
       this.pendingCommands.push(command);
@@ -153,11 +151,13 @@ export class WebSocketApi<Events extends WebSocketEvents> extends (EventEmitter
   }
 
   protected flush() {
-    for (const command of this.pendingCommands) {
+    const commands = this.pendingCommands;
+
+    this.pendingCommands = [];
+
+    for (const command of commands) {
       this.send(command);
     }
-
-    this.pendingCommands.length = 0;
   }
 
   protected _onOpen(evt: Event) {
