@@ -3,25 +3,23 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import type {
-  IReleaseUpdatePayload } from "../../../../common/k8s-api/endpoints/helm-releases.api";
-import {
-  updateRelease,
-} from "../../../../common/k8s-api/endpoints/helm-releases.api";
 import releasesInjectable from "../releases.injectable";
+import type { CallForHelmReleaseUpdate } from "./call-for-helm-release-update/call-for-helm-release-update.injectable";
+import callForHelmReleaseUpdateInjectable from "./call-for-helm-release-update/call-for-helm-release-update.injectable";
 
 const updateReleaseInjectable = getInjectable({
   id: "update-release",
 
-  instantiate: (di) => {
+  instantiate: (di): CallForHelmReleaseUpdate => {
     const releases = di.inject(releasesInjectable);
+    const callForHelmReleaseUpdate = di.inject(callForHelmReleaseUpdateInjectable);
 
     return async (
-      name: string,
-      namespace: string,
-      payload: IReleaseUpdatePayload,
+      name,
+      namespace,
+      payload,
     ) => {
-      const result = await updateRelease(name, namespace, payload);
+      const result = await callForHelmReleaseUpdate(name, namespace, payload);
 
       releases.invalidate();
 
