@@ -1,3 +1,9 @@
+/**
+ * Copyright (c) OpenLens Authors. All rights reserved.
+ * Licensed under MIT License. See LICENSE in root directory for more information.
+ */
+import type { IComputedValue } from "mobx";
+
 /**
  * Copyright (c) OpenLens Authors. All rights reserved.
  * Licensed under MIT License. See LICENSE in root directory for more information.
@@ -9,4 +15,5 @@ interface WorkloadsOverviewDetailComponents {
 export interface WorkloadsOverviewDetailRegistration {
   components: WorkloadsOverviewDetailComponents;
   priority?: number;
+  visible?: IComputedValue<boolean>;
 }
