@@ -5,16 +5,16 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { workloadInjectionToken } from "../workload-injection-token";
 import { ResourceNames } from "../../../../utils/rbac";
-import navigateToPodsInjectable from "../../../../../common/front-end-routing/routes/cluster/workloads/deployments/navigate-to-deployments.injectable";
 import namespaceStoreInjectable from "../../../+namespaces/store.injectable";
 import statefulsetsStoreInjectable from "../../../+workloads-statefulsets/store.injectable";
 import { computed } from "mobx";
+import navigateToStatefulsetsInjectable from "../../../../../common/front-end-routing/routes/cluster/workloads/statefulsets/navigate-to-statefulsets.injectable";
 
 const statefulsetsWorkloadInjectable = getInjectable({
   id: "statefulsets-workload",
 
   instantiate: (di) => {
-    const navigate = di.inject(navigateToPodsInjectable);
+    const navigate = di.inject(navigateToStatefulsetsInjectable);
     const namespaceStore = di.inject(namespaceStoreInjectable);
     const store = di.inject(statefulsetsStoreInjectable);
 
