@@ -4,13 +4,13 @@
  */
 
 import React from "react";
-import { secretsApi } from "../../../../../../common/k8s-api/endpoints";
+import { secretApi } from "../../../../../../common/k8s-api/endpoints";
 import { DrawerItem } from "../../../../drawer";
 import type { VolumeVariantComponent } from "../variant-helpers";
 import { LocalRef } from "../variant-helpers";
 
 export const FlexVolume: VolumeVariantComponent<"flexVolume"> = (
-  ({ pod, variant: { driver, fsType, secretRef, readOnly = false, options }}) => (
+  ({ pod, variant: { driver, fsType, secretRef, readOnly = false, options = {}}}) => (
     <>
       <DrawerItem name="Driver">
         {driver}
@@ -22,13 +22,13 @@ export const FlexVolume: VolumeVariantComponent<"flexVolume"> = (
         pod={pod}
         title="Secret"
         kubeRef={secretRef}
-        api={secretsApi}
+        api={secretApi}
       />
       <DrawerItem name="Readonly">
         {readOnly.toString()}
       </DrawerItem>
       {
-        ...Object.entries(options)
+        Object.entries(options)
           .map(([key, value]) => (
             <DrawerItem key={key} name={`Option: ${key}`}>
               {value}
