@@ -23,8 +23,8 @@ const spec: PodSpec = {
       },
     },
     terminationMessagePath: "test",
-    terminationMessagePolicy: "test",
-    imagePullPolicy: "test",
+    terminationMessagePolicy: "File",
+    imagePullPolicy: "Always",
   }],
   restartPolicy: "restart",
   terminationGracePeriodSeconds: 1200,
