@@ -4,7 +4,7 @@
  */
 
 import { getInjectable } from "@ogre-tools/injectable";
-import { observable } from "mobx";
+import { action, observable } from "mobx";
 import React from "react";
 
 export class CommandOverlay {
@@ -14,17 +14,17 @@ export class CommandOverlay {
     return Boolean(this.#component.get());
   }
 
-  open = (component: React.ReactElement) => {
+  open = action((component: React.ReactElement) => {
     if (!React.isValidElement(component)) {
       throw new TypeError("CommandOverlay.open must be passed a valid ReactElement");
     }
 
     this.#component.set(component);
-  };
+  });
 
-  close = () => {
+  close = action(() => {
     this.#component.set(null);
-  };
+  });
 
   get component(): React.ReactElement | null {
     return this.#component.get();
