@@ -5,7 +5,7 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { InstallChartTabStore } from "./store";
 import createDockTabStoreInjectable from "../dock-tab-store/create-dock-tab-store.injectable";
-import type { IReleaseUpdateDetails } from "../../../../common/k8s-api/endpoints/helm-releases.api";
+import type { HelmReleaseUpdateDetails } from "../../../../common/k8s-api/endpoints/helm-releases.api";
 import createStorageInjectable from "../../../utils/create-storage/create-storage.injectable";
 
 const installChartTabStoreInjectable = getInjectable({
@@ -17,7 +17,7 @@ const installChartTabStoreInjectable = getInjectable({
     return new InstallChartTabStore({
       createStorage: di.inject(createStorageInjectable),
       versionsStore: createDockTabStore<string[]>(),
-      detailsStore: createDockTabStore<IReleaseUpdateDetails>(),
+      detailsStore: createDockTabStore<HelmReleaseUpdateDetails>(),
     });
   },
 });
