@@ -8,7 +8,7 @@ import { Icon } from "../../icon";
 export function ToBottom({ onClick }: { onClick: () => void }) {
   return (
     <button
-      className="absolute top-3 right-3 z-10 rounded-md flex align-center px-1.5 py-1.5 pl-3.5"
+      className="absolute top-3 right-3 z-10 rounded-md flex align-center px-1 py-1 pl-3"
       style={{ backgroundColor: "var(--blue)" }}
       onClick={evt => {
         evt.currentTarget.blur();
