@@ -5,6 +5,7 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { when } from "mobx";
 import { TerminalChannels } from "../../../../common/terminal/channels";
+import { waitUntilDefined } from "../../../../common/utils/wait";
 import type { TerminalApi } from "../../../api/terminal-api";
 import { noop } from "../../../utils";
 import { Notifications } from "../../notifications";
@@ -16,7 +17,7 @@ import getTerminalApiInjectable from "./get-terminal-api.injectable";
 interface Dependencies {
   selectTab: (tabId: TabId) => void;
   createTerminalTab: () => DockTab;
-  getTerminalApi: (tabId: TabId) => TerminalApi;
+  getTerminalApi: (tabId: TabId) => TerminalApi | undefined;
 }
 
 export interface SendCommandOptions {
@@ -37,7 +38,7 @@ export interface SendCommandOptions {
 }
 
 const sendCommand = ({ selectTab, createTerminalTab, getTerminalApi }: Dependencies) => async (command: string, options: SendCommandOptions = {}): Promise<void> => {
-  let { tabId } = options;
+  let tabId: string | undefined = options.tabId;
 
   if (tabId) {
     selectTab(tabId);
@@ -45,10 +46,12 @@ const sendCommand = ({ selectTab, createTerminalTab, getTerminalApi }: Dependenc
     tabId = createTerminalTab().id;
   }
 
-  await when(() => Boolean(getTerminalApi(tabId)));
-
-  const terminalApi = getTerminalApi(tabId);
-  const shellIsReady = when(() =>terminalApi.isReady);
+  const terminalApi = await waitUntilDefined(() => (
+    tabId
+      ? getTerminalApi(tabId)
+      : undefined
+  ));
+  const shellIsReady = when(() => terminalApi.isReady);
   const notifyVeryLong = setTimeout(() => {
     shellIsReady.cancel();
     Notifications.info(
