@@ -62,13 +62,7 @@ const NonInjectedKubeObjectMeta = observer(({
       <DrawerItem name="Created" hidden={isHidden("creationTimestamp")}>
         <KubeObjectAge object={object} compact={false} />
         {" ago "}
-        {creationTimestamp && (
-          <>
-            (
-            <LocaleDate date={creationTimestamp} />
-            )
-          </>
-        )}
+        {creationTimestamp && <LocaleDate date={creationTimestamp} />}
       </DrawerItem>
       <DrawerItem name="Name" hidden={isHidden("name")}>
         {getName()}
