@@ -9,7 +9,8 @@ import { Icon } from "../icon";
 export function NoMetrics() {
   return (
     <div className="flex justify-center align-center">
-      <Icon material="info"/>&nbsp;Metrics not available at the moment
+      <Icon material="info"/>
+&nbsp;Metrics not available at the moment
     </div>
   );
 }
