@@ -8,27 +8,30 @@ import "./table-row.scss";
 import type { CSSProperties } from "react";
 import React from "react";
 import { cssNames } from "../../utils";
-import type { ItemObject } from "../../../common/item.store";
 
-export type TableRowElem = React.ReactElement<TableRowProps>;
+export type TableRowElem<Item> = React.ReactElement<TableRowProps<Item>>;
 
-export interface TableRowProps extends React.DOMAttributes<HTMLDivElement> {
+export interface TableRowProps<Item> extends React.DOMAttributes<HTMLDivElement> {
   className?: string;
   selected?: boolean;
   style?: CSSProperties;
   nowrap?: boolean; // white-space: nowrap, align inner <TableCell> in one line
-  sortItem?: ItemObject | any; // data for sorting callback in <Table sortable={}/>
-  searchItem?: ItemObject | any; // data for searching filters in <Table searchable={}/>
+  sortItem?: Item; // data for sorting callback in <Table sortable={}/>
+  searchItem?: Item; // data for searching filters in <Table searchable={}/>
   disabled?: boolean;
+  testId?: string;
 }
 
-export class TableRow extends React.Component<TableRowProps> {
+export class TableRow<Item> extends React.Component<TableRowProps<Item>> {
   render() {
-    const { className, nowrap, selected, disabled, children, sortItem, searchItem, ...rowProps } = this.props;
+    const { className, nowrap, selected, disabled, children, sortItem, searchItem, testId, ...rowProps } = this.props;
     const classNames = cssNames("TableRow", className, { selected, nowrap, disabled });
 
     return (
-      <div className={classNames} {...rowProps}>
+      <div
+        className={classNames}
+        data-testid={testId}
+        {...rowProps}>
         {children}
       </div>
     );
