@@ -10,28 +10,26 @@ import writeJsonFileInjectable from "../../../common/fs/write-json-file.injectab
 import { observable } from "mobx";
 import loggerInjectable from "../../../common/logger.injectable";
 import getAbsolutePathInjectable from "../../../common/path/get-absolute-path.injectable";
+import hostedClusterIdInjectable from "../../cluster-frame-context/hosted-cluster-id.injectable";
+import storageSaveDelayInjectable from "./storage-save-delay.injectable";
 
 const createStorageInjectable = getInjectable({
   id: "create-storage",
 
-  instantiate: (di) =>
-    createStorage({
-      storage: observable({
-        initialized: false,
-        loaded: false,
-        data: {} as Record<string /*key*/, any>, // json-serializable
-      }),
-
-      readJsonFile: di.inject(readJsonFileInjectable),
-      writeJsonFile: di.inject(writeJsonFileInjectable),
-      logger: di.inject(loggerInjectable),
-
-      directoryForLensLocalStorage: di.inject(
-        directoryForLensLocalStorageInjectable,
-      ),
-
-      getAbsolutePath: di.inject(getAbsolutePathInjectable),
+  instantiate: (di) => createStorage({
+    storage: observable({
+      initialized: false,
+      loaded: false,
+      data: {},
     }),
+    readJsonFile: di.inject(readJsonFileInjectable),
+    writeJsonFile: di.inject(writeJsonFileInjectable),
+    logger: di.inject(loggerInjectable),
+    directoryForLensLocalStorage: di.inject(directoryForLensLocalStorageInjectable),
+    getAbsolutePath: di.inject(getAbsolutePathInjectable),
+    hostedClusterId: di.inject(hostedClusterIdInjectable),
+    saveDelay: di.inject(storageSaveDelayInjectable),
+  }),
 });
 
 export default createStorageInjectable;
