@@ -6,7 +6,10 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import type { Disposer } from "../utils";
 
-function addWindowEventListener<K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => any, options?: boolean | AddEventListenerOptions): Disposer {
+export type AddWindowEventListener = typeof addWindowEventListener;
+export type WindowEventListener<K extends keyof WindowEventMap> = (this: Window, ev: WindowEventMap[K]) => any;
+
+function addWindowEventListener<K extends keyof WindowEventMap>(type: K, listener: WindowEventListener<K>, options?: boolean | AddEventListenerOptions): Disposer {
   window.addEventListener(type, listener, options);
 
   return () => void window.removeEventListener(type, listener);
